A Python library for Klaviyo's API

## Installation

You can install this library using the `pip` tool.

Depending on your system configuration, you will need to run the following shell command:

`pip install klaviyo-sdk`

OR 

`pip3 install klaviyo-sdk`

## Import

To import this package, run the following Python command:

`import klaviyo_sdk`

## Using this Library

Documentation specific to this library can be found [here](https://github.com/klaviyo/klaviyo-python)

## Using the Klaviyo API

Documentation for Klaviyo's API can be found [here](https://developers.klaviyo.com/en/reference/api-overview)

NOTE: sample API calls featured in the API docs do NOT use this library or others; rather, they make outright HTTP calls.

## Setting up a Klaviyo Account

Sign up for a free Klaviyo account [here](https://www.klaviyo.com/)



